intelmq.bots.collectors.http package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.collectors.http package

## Submodules

## intelmq.bots.collectors.http.collector_http module

HTTP collector bot

Parameters: http_url: string http_header: dictionary

> default: {}

http_verify_cert: boolean

  default: True

extract_files: value used to extract files from downloaded compressed file

  default: None all: True; some: string with file names separated by ,

http_url_formatting: bool|json to turn on time formatting (and to specify delta to current time) http_username, http_password: string http_proxy, https_proxy: string http_timeout_sec: tuple of two floats or float http_timeout_max_tries: an integer depicting how often a connection attempt is retried verify_pgp_signatures: whether to download and check file signatures

> default: False

signature_url: string signature_url_formatting: the same as http_url_formatting gpg_keyring: none (defaults to user’s GPG keyring) or string (path to keyring file)

`intelmq.bots.collectors.http.collector_http.` `BOT`

  alias of `intelmq.bots.collectors.http.collector_http.HTTPCollectorBot`

class `intelmq.bots.collectors.http.collector_http.` `HTTPCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  `format_url`(url: str, formatting) → str
  `init`()
  `process`()
  `verify_signature`(data: bytes)

    Download signature file and verify the report data.

class `intelmq.bots.collectors.http.collector_http.` `Time`(delta=None)

  Bases: `object`

  `__init__`(delta=None)

    Delta is a datetime.timedelta JSON string, ex: ‘{“days”=-1}’.

## intelmq.bots.collectors.http.collector_http_stream module

HTTP collector bot

Parameters: http_url: string http_header: dictionary

> default: {}

http_verify_cert: boolean

  default: True

http_username, http_password: string http_proxy, https_proxy: string strip_lines: boolean http_timeout_sec: tuple of two floats or float

`intelmq.bots.collectors.http.collector_http_stream.` `BOT`

  alias of `intelmq.bots.collectors.http.collector_http_stream.HTTPStreamCollectorBot`

class `intelmq.bots.collectors.http.collector_http_stream.` `HTTPStreamCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  `init`()
  `process`()
  `sighup_delay` = False

## Module contents